I believe that the model here is a fork of the one stored here: https://simtk.org/frs/?group_id=773

Actually, it comes from Pose2Sim...which forked it from someone else..going to be a chain of attribution.
